@@ -7,6 +7,7 @@ irrespective of what has been deposited with the U.S. Copyright Office.
 
 Copyright (c) 2020 Red Hat, Inc.
 */
+// Copyright Contributors to the Open Cluster Management project
 
 package handlers
 
@@ -15,7 +16,6 @@ import (
 	"net/http"
 
 	"github.com/golang/glog"
-	db "github.com/stolostron/search-aggregator/pkg/dbconnector"
 )
 
 // LivenessProbe is used to check if this service is alive.
@@ -30,15 +30,15 @@ func ReadinessProbe(w http.ResponseWriter, r *http.Request) {
 
 	// Go straight to the pool's Dial because we don't actually want to play by the pool's
 	// rules here - just want a connection unrelated to all the other ones,
-	conn, err := db.Pool.Dial()
-	if err != nil {
-		// Respond with error.
-		glog.Warning("Unable to reach Redis.")
-		http.Error(w, "Unable to reach Redis.", 503)
-		return
-	}
+	// conn, err := db.Pool.Dial()
+	// if err != nil {
+	// 	// Respond with error.
+	// 	glog.Warning("Unable to reach Redis.")
+	// 	http.Error(w, "Unable to reach Redis.", 503)
+	// 	return
+	// }
 
-	defer conn.Close()
+	// defer conn.Close()
 	// Respond with success
 	fmt.Fprint(w, "OK")
 }
